@@ -1,4 +1,4 @@
-context("Predictor")
+skip_if_not_installed("mlr3")
 
 test_that("Predictor class instantiation", {
   skip_on_cran()
@@ -19,6 +19,7 @@ test_that("ConstantPredictor", {
 
 test_that("LearnerPredictor - response", {
   skip_on_cran()
+  skip_if_not_installed("mlr3learners") 
   prd = LearnerPredictor$new(lrn("classif.rpart"))
   expect_class(prd, "LearnerPredictor")
   prd$fit(iris[1:100,1:4], factor(iris$Species[1:100]))
@@ -29,6 +30,7 @@ test_that("LearnerPredictor - response", {
 
 test_that("LearnerPredictor - probs", {
   skip_on_cran()
+  skip_if_not_installed("mlr3learners") 
   prd = LearnerPredictor$new(lrn("classif.rpart", predict_type = "prob"))
   expect_class(prd, "LearnerPredictor")
   prd$fit(iris[51:150,1:4], factor(iris$Species[51:150]))
